Cython Hash Table for Pre-Hashed Keys
-------------------------------------

Simple but high performance Cython hash table mapping pre-randomized keys to void* values.

Inspired by: http://preshing.com/20130107/this-hash-table-is-faster-than-a-judy-array/
